CodexClient

Struct CodexClient 

pub struct CodexClient {
    pub cli_path: String,
}
Builder / factory for codex executions.

Holds configuration that applies to every execution, such as the path to the codex binary.

Fields

cli_path: String

Path to the codex CLI binary.

Implementations

Source

impl CodexClient

pub fn new() -> Self

Create a new client that will look for codex on $PATH.

pub fn with_cli_path(path: impl Into<String>) -> Self

Create a new client with a custom path to the codex CLI binary.

pub async fn exec(&self, prompt: &str, opts: ExecOptions) -> Result<Execution>

Start a new codex execution with the given prompt and options.

This spawns the codex exec --json subprocess and returns an Execution handle for reading events.

Errors

Returns SdkError::ProcessSpawn if the codex binary cannot be found or started.

pub async fn exec_resume( &self, prompt: &str, opts: ResumeOptions, ) -> Result<Execution>

Resume a previous codex execution.

Errors

Returns SdkError::ProcessSpawn if the codex binary cannot be found or started.